==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/covermanager/translations/covermanager_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation>Εμφάνιση εξώφυλλου</translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="30"/>
        <source>Cover Manager Plugin</source>
        <translation>Πρόσθετο διαχείρισης εξώφυλλων</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="50"/>
        <source>About Cover Manager Plugin</source>
        <translation>Σχετικά με το πρόσθετο διαχείρισης εξώφυλλων</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation>Qmmp πρόσθετο διαχείρισης εξώφυλλων</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Αποθήκευση ως...</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation>Τρέχον μέγεθος</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation>128x128</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation>256x256</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation>512x512</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation>1024x1024</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation>Alt+F4</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation>Αποθήκευση εξώφυλλου ως</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation>Εικόνες</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/covermanager/translations/covermanager_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation>Εμφάνιση εξώφυλλου</translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="30"/>
        <source>Cover Manager Plugin</source>
        <translation>Πρόσθετο διαχείρισης εξώφυλλων</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="50"/>
        <source>About Cover Manager Plugin</source>
        <translation>Σχετικά με το πρόσθετο διαχείρισης εξώφυλλων</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation>Qmmp πρόσθετο διαχείρισης εξώφυλλων</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Αποθήκευση ως...</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation>Τρέχον μέγεθος</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation>128x128</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation>256x256</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation>512x512</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation>1024x1024</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation>Alt+F4</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation>Αποθήκευση εξώφυλλου ως</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation>Εικόνες</translation>
    </message>
</context>
</TS>
